pub struct BudgetResolutionError {
pub cause: Option<String>,
}Expand description
Error indicating a failure to resolve context budget limits.
Fields
cause: Option<String>Detailed cause of the budget resolution failure, if available.
Implementations