pub struct MaxIterationsError {
pub iterations: i64,
pub completed_steps: IndexMap<String, ()>,
pub pending_steps: Vec<String>,
}Expand description
Error indicating that a workflow reached its maximum allowed iteration limit.
Fields
iterations: i64The iteration limit that was reached.
completed_steps: IndexMap<String, ()>Steps that were successfully completed before reaching the limit.
pending_steps: Vec<String>Steps that are still pending when execution was terminated.
Implementations