pub struct UnsupportedModelError {
pub model: String,
}Expand description
Error indicating that a model is not supported because sampling defaults are missing and strict mode is active.
Fields
model: StringThe name of the unsupported model.
Implementations